@@ -2,7 +2,6 @@ import logging
 import random
 import subprocess
 import click
-from collections import OrderedDict
 
 # see http://golang.org/src/pkg/crypto/x509/root_unix.go
 from pathlib import Path
@@ -35,8 +34,7 @@ def generate_help_tree(commands):
         if not commands or len(commands) == index:
             return structure
 
-        commands = OrderedDict(sorted(commands.items(), key=lambda t: t[0]))
-        keys = list(commands.keys())
+        keys = sorted(commands.keys())
 
         if isinstance(commands[keys[index]], click.core.Group):
             structure.append({
